.. ndslib documentation master file, created by
   sphinx-quickstart on Tue Dec 20 12:37:26 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

`ndslib`
========

This software is companion to the book "Neuroimaging and Data Science"
by Ariel Rokem and Tal Yarkoni. An online version of the book can be found at
`https://neuroimaging-data-science.org <https://neuroimaging-data-science.org>`_.

These are the functions available through the software:

.. autofunction:: ndslib.data.load_data

.. autofunction:: ndslib.data.download_bids_dataset

.. autofunction:: ndslib.viz.imshow_with_annot

.. autofunction:: ndslib.viz.plot_diffeomorphic_map

.. autofunction:: ndslib.viz.plot_coef_path

.. autofunction:: ndslib.viz.plot_train_test

.. autofunction:: ndslib.viz.plot_learning_curves

.. autofunction:: ndslib.viz.plot_graphviz_tree

.. autofunction:: ndslib.image.gaussian_kernel
